<?php

namespace EventPortal\Domain\EventDelegate\Actions;

use EventPortal\Contracts\Event;
use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\EventDelegate\Events\EventDelegatesAssociatedToEvent;

class AssociateToEvent
{
    public function execute(Event $event, array $delegates): void
    {
        $currentDelegates = $event->fresh()->delegates;

        $delegates = collect($delegates)
            ->mapWithKeys(function ($delegate) {
                return [$delegate => ['status' => 'candidate']];
            })
            // phpcs:disable Generic.CodeAnalysis.UnusedFunctionParameter
            ->reject(function ($data, $delegateId) use ($currentDelegates) {
            // phpcs:enable
                return $currentDelegates->contains('id', $delegateId);
            })
            ->toArray();

        $event->delegates()->attach($delegates, [
            'pathway_id' => Pathway::defaultForEvent($event)->first()->id,
        ]);

        event(new EventDelegatesAssociatedToEvent($event));
    }
}
