<?php

namespace EventPortal\Http\Controllers\Admin\Event;

use EventPortal\Domain\Event\Actions\TransitionEvent;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Exceptions\CannotChangeEventState;
use EventPortal\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use SM\SMException;

class EventTransitionController extends Controller
{
    public function __construct()
    {
        $this->middleware('check-permission:event.update');
    }

    public function __invoke(Event $event, TransitionEvent $action): RedirectResponse
    {
        try {
            $action->execute($event, request()->type);
            toast()->success(trans('event.transitioned'));
        } catch (SMException $exception) {
            report($exception);
            toast()->error(trans('event.error'));
        } catch (CannotChangeEventState $exception) {
            toast()->error(trans('event.action-list.cannot-change-state'));
        }

        return redirect()->route('admin.event.show', ['event' => $event]);
    }
}
