<?php

namespace EventPortal\Tests\Feature\Admin\Event\ActionList;

use EventPortal\Domain\ActionList\Models\ActionList;
use EventPortal\Domain\ActionList\Models\Task;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class ToggleTaskTest extends TestCase
{
    use RefreshDatabase, SeedRolesAndPermissions;

    /** @test */
    public function mark_task_as_completed()
    {
        $event = factory(Event::class)->create([
            'status' => 'test',
        ]);

        $actionList = factory(ActionList::class)->create([
            'status' => 'test',
            'type' => 'default',
            'event_id' => $event->id,
        ]);

        $task = factory(Task::class)->create([
            'action_list_id' => $actionList->id,
            'name' => 'venue',
        ]);

        $this->assertNull($task->completed_at);

        $this->actingAsAdmin()->post(route('admin.task.toggle', $task));

        $this->assertNotNull($task->refresh()->completed_at);
        $this->assertNotNull($task->refresh()->user_id);
    }

    /** @test */
    public function mark_task_as_incomplete()
    {
        $event = factory(Event::class)->create([
            'status' => 'test',
        ]);

        $actionList = factory(ActionList::class)->create([
            'status' => 'test',
            'type' => 'default',
            'event_id' => $event->id,
        ]);

        $task = factory(Task::class)
            ->state('completed')
            ->create([
                'action_list_id' => $actionList->id,
                'name' => 'venue',
            ]);

        $this->assertNotNull($task->completed_at);

        $this->actingAsAdmin()->post(route('admin.task.toggle', $task));

        $this->assertNull($task->refresh()->completed_at);
        $this->assertNull($task->refresh()->user_id);
    }
}
