<?php

namespace EventPortal\Tests\Unit\ActionList\Models;

use EventPortal\Domain\ActionList\Models\ActionList;
use EventPortal\Domain\ActionList\Models\Task;
use EventPortal\Domain\User\Models\User;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class ActionListTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_get_related_tasks()
    {
        $actionList = factory(ActionList::class)->create();
        $taskA = factory(Task::class)->create(['action_list_id' => $actionList->id]);
        $taskB = factory(Task::class)->create(['action_list_id' => $actionList->id]);

        $this->assertCount(2, $actionList->tasks);
        $this->assertContainsModel($taskA, $actionList->tasks);
        $this->assertContainsModel($taskB, $actionList->tasks);
    }

    /** @test **/
    public function can_complete_all_tasks()
    {
        $user = factory(User::class)->create();
        $actionList = factory(ActionList::class)->create();
        $taskA = factory(Task::class)->create(['action_list_id' => $actionList->id]);
        $taskB = factory(Task::class)->create(['action_list_id' => $actionList->id]);

        $actionList->complete($user);

        $this->assertTrue($taskA->fresh()->is_complete);
        $this->assertTrue($taskB->fresh()->is_complete);
    }

    /** @test **/
    public function can_get_number_outstanding_tasks()
    {
        $actionList = factory(ActionList::class)->create();
        factory(Task::class)->create(['action_list_id' => $actionList->id]);
        factory(Task::class)->state('completed')->create(['action_list_id' => $actionList->id]);
        factory(Task::class)->create(['action_list_id' => $actionList->id]);

        $this->assertSame($actionList->num_outstanding_tasks, 2);
    }
}
