<?php

namespace EventPortal\Tests\Unit\Component\Filter;

use Carbon\Carbon;
use EventPortal\Domain\Component\Filter\DateFilter;
use EventPortal\Tests\Support\TestModel;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class DateFilterTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function type_is_correct(): void
    {
        $filter = DateFilter::make('Date');

        $this->assertSame('DateInput', $filter->type);
    }

    /** @test **/
    public function can_filter_by_date(): void
    {
        $modelA = factory(TestModel::class)->create(['created_at' => Carbon::parse('24th March 2021 10:30:00')]);
        $modelB = factory(TestModel::class)->create(['created_at' => Carbon::parse('29th March 2021 11:30:00')]);

        $query = TestModel::query();

        $filter = DateFilter::make('Date');

        $query = $filter->lookup->__invoke($query, '2021-03-29 11:30:00', 'created_at');

        $actual = $query->get();

        $this->assertNotContainsModel($modelA, $actual);
        $this->assertContainsModel($modelB, $actual);
    }
}
