<?php

namespace EventPortal\Tests\Unit\Component\Filter;

use EventPortal\Domain\Component\Filter\MultiSelectDropdownFilter;
use EventPortal\Domain\Component\Option;
use EventPortal\Tests\Support\TestModel;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class MultiSelectDropdownFilterTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function type_is_correct(): void
    {
        $filter = MultiSelectDropdownFilter::make('Type');

        $this->assertSame('MultiSelect', $filter->type);
    }

    /** @test **/
    public function can_filter_by_single_choice(): void
    {
        $eventA = factory(TestModel::class)->create(['type' => Option::make('Type A')]);
        $eventB = factory(TestModel::class)->create(['type' => Option::make('Type B')]);

        $query = TestModel::query();

        $filter = MultiSelectDropdownFilter::make('Type');

        $query = $filter->lookup->__invoke($query, 'type_b', 'type');

        $actual = $query->get();

        $this->assertNotContainsModel($eventA, $actual);
        $this->assertContainsModel($eventB, $actual);
    }

    /** @test **/
    public function can_filter_by_multi_choice(): void
    {
        $eventA = factory(TestModel::class)->create(['type' => Option::make('Type A')]);
        $eventB = factory(TestModel::class)->create(['type' => Option::make('Type B')]);
        $eventC = factory(TestModel::class)->create(['type' => Option::make('Type C')]);

        $query = TestModel::query();

        $filter = MultiSelectDropdownFilter::make('Type');

        $query = $filter->lookup->__invoke($query, ['type_b', 'type_c'], 'type');

        $actual = $query->get();

        $this->assertNotContainsModel($eventA, $actual);
        $this->assertContainsModel($eventB, $actual);
        $this->assertContainsModel($eventC, $actual);
    }
}
